# Yasta

![Yasta logo](https://i.imgur.com/MGw6TNI_d.webp?maxwidth=760)

Yasta is a modern task runner written in Python, it's also what we call microbus drivers in Egypt! 🚐

Yasta makes running and managing your tasks a breeze! 🌬️

# How to install

```
pip install yasta
```

# How to use

Yasta consists of 5 commands

1. init (initializes a pyproject.toml file with a test command)
2. add (adds a task to the list of tasks)
3. delete (deletes a task from the list of tasks)
4. show (shows the tables of tasks)
5. run (runs a task)

You can know more about the commands and flags by running

```
yasta --help
```

# Example

![Yasta init, adding and running tasks](https://i.imgur.com/Y55f9AN_d.webp?maxwidth=1520)

![Yasta force running commands, ignoring failed tasks](https://i.imgur.com/FsOrx3X_d.webp?maxwidth=1520)
